@@ -117,6 +117,9 @@ class MetaFieldType(type):
 
 
 class FieldType(metaclass=MetaFieldType):
+    default_value = None
+    lookups = {}
+
     def __init__(self):
         assert False
 
@@ -167,15 +170,15 @@ class NumberFieldType(FieldType):
         return float(value)
 
 
-class TimeFieldType(FieldType):
+class DateTimeFieldType(FieldType):
     default_value = "now"
     lookups = {
-        "equals": "time",
-        "not_equals": "time",
-        "gt": "time",
-        "gte": "time",
-        "lt": "time",
-        "lte": "time",
+        "equals": "datetime",
+        "not_equals": "datetime",
+        "gt": "datetime",
+        "gte": "datetime",
+        "lt": "datetime",
+        "lte": "datetime",
         "is_null": "boolean",
     }
 
@@ -190,9 +193,68 @@ class TimeFieldType(FieldType):
         return str(timezone.make_naive(value)) if value else None
 
 
+class DateFieldType(FieldType):
+    default_value = "today"
+    lookups = {
+        "equals": "date",
+        "not_equals": "date",
+        "gt": "date",
+        "gte": "date",
+        "lt": "date",
+        "lte": "date",
+        "is_null": "boolean",
+    }
+
+    @staticmethod
+    def parse(value):
+        if value.lower().strip() == "today":
+            return timezone.now().date()
+        return timezone.make_aware(dateutil.parser.parse(value)).date()
+
+    @staticmethod
+    def format(value):
+        return str(value) if value else None
+
+
+class WeekDayFieldType(FieldType):
+    @staticmethod
+    def format(value):
+        days = [
+            None,
+            "Sunday",
+            "Monday",
+            "Tuesday",
+            "Wednesday",
+            "Thursday",
+            "Friday",
+            "Saturday",
+        ]
+        return days[value] if value else None
+
+
+class MonthFieldType(FieldType):
+    @staticmethod
+    def format(value):
+        days = [
+            None,
+            "January",
+            "Feburary",
+            "March",
+            "April",
+            "May",
+            "June",
+            "July",
+            "August",
+            "September",
+            "October",
+            "November",
+            "December",
+        ]
+        return days[value] if value else None
+
+
 class HTMLFieldType(FieldType):
-    default_value = None
-    lookups = {}
+    pass
 
 
 class BooleanFieldType(FieldType):
@@ -210,16 +272,7 @@ class BooleanFieldType(FieldType):
             raise ValueError("Expected 'true' or 'false'")
 
 
-TYPES = {
-    field_type.name: field_type
-    for field_type in [
-        StringFieldType,
-        NumberFieldType,
-        TimeFieldType,
-        BooleanFieldType,
-        HTMLFieldType,
-    ]
-}
+TYPES = {field_type.name: field_type for field_type in FieldType.__subclasses__()}
 
 
 class BoundFieldMixin:
@@ -250,8 +303,9 @@ class BoundFilter(BoundFieldMixin):
         if self.lookup not in lookups:
             self.err_message = f"Bad lookup '{self.lookup}' expected {lookups}"
         else:
+            type_ = TYPES[lookups[self.lookup]]
             try:
-                self.parsed = TYPES[lookups[self.lookup]].parse(self.value)
+                self.parsed = type_.parse(self.value)
             except Exception as e:
                 self.err_message = str(e) if str(e) else repr(e)
 
