@@ -43,9 +43,9 @@ snapshots["test_query_html context"] = {
                     },
                     "date_joined": {
                         "concrete": True,
-                        "model": "time",
+                        "model": "datetime",
                         "prettyName": "date_joined",
-                        "type": "time",
+                        "type": "datetime",
                     },
                     "email": {
                         "concrete": True,
@@ -85,9 +85,9 @@ snapshots["test_query_html context"] = {
                     },
                     "last_login": {
                         "concrete": True,
-                        "model": "time",
+                        "model": "datetime",
                         "prettyName": "last_login",
-                        "type": "time",
+                        "type": "datetime",
                     },
                     "last_name": {
                         "concrete": True,
@@ -150,9 +150,9 @@ snapshots["test_query_html context"] = {
                     },
                     "created_time": {
                         "concrete": True,
-                        "model": "time",
+                        "model": "datetime",
                         "prettyName": "created_time",
-                        "type": "time",
+                        "type": "datetime",
                     },
                     "description": {
                         "concrete": True,
@@ -237,7 +237,132 @@ snapshots["test_query_html context"] = {
                     "query",
                 ],
             },
+            "date": {
+                "fields": {
+                    "count": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "count",
+                        "type": "number",
+                    },
+                    "day": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "day",
+                        "type": "number",
+                    },
+                    "month": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "month",
+                        "type": "month",
+                    },
+                    "quarter": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "quarter",
+                        "type": "number",
+                    },
+                    "week_day": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "week_day",
+                        "type": "weekday",
+                    },
+                    "year": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "year",
+                        "type": "number",
+                    },
+                },
+                "sortedFields": [
+                    "count",
+                    "day",
+                    "month",
+                    "quarter",
+                    "week_day",
+                    "year",
+                ],
+            },
+            "datetime": {
+                "fields": {
+                    "count": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "count",
+                        "type": "number",
+                    },
+                    "date": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "date",
+                        "type": "date",
+                    },
+                    "day": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "day",
+                        "type": "number",
+                    },
+                    "hour": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "hour",
+                        "type": "number",
+                    },
+                    "minute": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "minute",
+                        "type": "number",
+                    },
+                    "month": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "month",
+                        "type": "month",
+                    },
+                    "quarter": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "quarter",
+                        "type": "number",
+                    },
+                    "second": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "second",
+                        "type": "number",
+                    },
+                    "week_day": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "week_day",
+                        "type": "weekday",
+                    },
+                    "year": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "year",
+                        "type": "number",
+                    },
+                },
+                "sortedFields": [
+                    "count",
+                    "date",
+                    "day",
+                    "hour",
+                    "minute",
+                    "month",
+                    "quarter",
+                    "second",
+                    "week_day",
+                    "year",
+                ],
+            },
             "html": {"fields": {}, "sortedFields": []},
+            "month": {"fields": {}, "sortedFields": []},
             "number": {
                 "fields": {
                     "average": {
@@ -465,9 +590,9 @@ snapshots["test_query_html context"] = {
                     },
                     "created_time": {
                         "concrete": True,
-                        "model": "time",
+                        "model": "datetime",
                         "prettyName": "created_time",
-                        "type": "time",
+                        "type": "datetime",
                     },
                     "default_sku": {
                         "concrete": False,
@@ -584,75 +709,7 @@ snapshots["test_query_html context"] = {
                 },
                 "sortedFields": ["id", "admin", "name"],
             },
-            "time": {
-                "fields": {
-                    "count": {
-                        "concrete": True,
-                        "model": None,
-                        "prettyName": "count",
-                        "type": "number",
-                    },
-                    "day": {
-                        "concrete": True,
-                        "model": None,
-                        "prettyName": "day",
-                        "type": "number",
-                    },
-                    "hour": {
-                        "concrete": True,
-                        "model": None,
-                        "prettyName": "hour",
-                        "type": "number",
-                    },
-                    "minute": {
-                        "concrete": True,
-                        "model": None,
-                        "prettyName": "minute",
-                        "type": "number",
-                    },
-                    "month": {
-                        "concrete": True,
-                        "model": None,
-                        "prettyName": "month",
-                        "type": "number",
-                    },
-                    "quarter": {
-                        "concrete": True,
-                        "model": None,
-                        "prettyName": "quarter",
-                        "type": "number",
-                    },
-                    "second": {
-                        "concrete": True,
-                        "model": None,
-                        "prettyName": "second",
-                        "type": "number",
-                    },
-                    "week_day": {
-                        "concrete": True,
-                        "model": None,
-                        "prettyName": "week_day",
-                        "type": "number",
-                    },
-                    "year": {
-                        "concrete": True,
-                        "model": None,
-                        "prettyName": "year",
-                        "type": "number",
-                    },
-                },
-                "sortedFields": [
-                    "count",
-                    "day",
-                    "hour",
-                    "minute",
-                    "month",
-                    "quarter",
-                    "second",
-                    "week_day",
-                    "year",
-                ],
-            },
+            "weekday": {"fields": {}, "sortedFields": []},
         },
         "baseUrl": "/data_browser/",
         "savedViews": [],
@@ -680,12 +737,62 @@ snapshots["test_query_html context"] = {
                 },
                 "sortedLookups": ["equals", "not_equals", "is_null"],
             },
+            "date": {
+                "defaultLookup": "equals",
+                "defaultValue": "today",
+                "lookups": {
+                    "equals": {"type": "date"},
+                    "gt": {"type": "date"},
+                    "gte": {"type": "date"},
+                    "is_null": {"type": "boolean"},
+                    "lt": {"type": "date"},
+                    "lte": {"type": "date"},
+                    "not_equals": {"type": "date"},
+                },
+                "sortedLookups": [
+                    "equals",
+                    "not_equals",
+                    "gt",
+                    "gte",
+                    "lt",
+                    "lte",
+                    "is_null",
+                ],
+            },
+            "datetime": {
+                "defaultLookup": "equals",
+                "defaultValue": "now",
+                "lookups": {
+                    "equals": {"type": "datetime"},
+                    "gt": {"type": "datetime"},
+                    "gte": {"type": "datetime"},
+                    "is_null": {"type": "boolean"},
+                    "lt": {"type": "datetime"},
+                    "lte": {"type": "datetime"},
+                    "not_equals": {"type": "datetime"},
+                },
+                "sortedLookups": [
+                    "equals",
+                    "not_equals",
+                    "gt",
+                    "gte",
+                    "lt",
+                    "lte",
+                    "is_null",
+                ],
+            },
             "html": {
                 "defaultLookup": None,
                 "defaultValue": None,
                 "lookups": {},
                 "sortedLookups": [],
             },
+            "month": {
+                "defaultLookup": None,
+                "defaultValue": None,
+                "lookups": {},
+                "sortedLookups": [],
+            },
             "number": {
                 "defaultLookup": "equals",
                 "defaultValue": 0,
@@ -738,27 +845,11 @@ snapshots["test_query_html context"] = {
                     "is_null",
                 ],
             },
-            "time": {
-                "defaultLookup": "equals",
-                "defaultValue": "now",
-                "lookups": {
-                    "equals": {"type": "time"},
-                    "gt": {"type": "time"},
-                    "gte": {"type": "time"},
-                    "is_null": {"type": "boolean"},
-                    "lt": {"type": "time"},
-                    "lte": {"type": "time"},
-                    "not_equals": {"type": "time"},
-                },
-                "sortedLookups": [
-                    "equals",
-                    "not_equals",
-                    "gt",
-                    "gte",
-                    "lt",
-                    "lte",
-                    "is_null",
-                ],
+            "weekday": {
+                "defaultLookup": None,
+                "defaultValue": None,
+                "lookups": {},
+                "sortedLookups": [],
             },
         },
         "version": "redacted",
@@ -807,7 +898,132 @@ snapshots["test_query_html_no_perms context"] = {
                 },
                 "sortedFields": ["average", "sum"],
             },
+            "date": {
+                "fields": {
+                    "count": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "count",
+                        "type": "number",
+                    },
+                    "day": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "day",
+                        "type": "number",
+                    },
+                    "month": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "month",
+                        "type": "month",
+                    },
+                    "quarter": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "quarter",
+                        "type": "number",
+                    },
+                    "week_day": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "week_day",
+                        "type": "weekday",
+                    },
+                    "year": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "year",
+                        "type": "number",
+                    },
+                },
+                "sortedFields": [
+                    "count",
+                    "day",
+                    "month",
+                    "quarter",
+                    "week_day",
+                    "year",
+                ],
+            },
+            "datetime": {
+                "fields": {
+                    "count": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "count",
+                        "type": "number",
+                    },
+                    "date": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "date",
+                        "type": "date",
+                    },
+                    "day": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "day",
+                        "type": "number",
+                    },
+                    "hour": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "hour",
+                        "type": "number",
+                    },
+                    "minute": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "minute",
+                        "type": "number",
+                    },
+                    "month": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "month",
+                        "type": "month",
+                    },
+                    "quarter": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "quarter",
+                        "type": "number",
+                    },
+                    "second": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "second",
+                        "type": "number",
+                    },
+                    "week_day": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "week_day",
+                        "type": "weekday",
+                    },
+                    "year": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "year",
+                        "type": "number",
+                    },
+                },
+                "sortedFields": [
+                    "count",
+                    "date",
+                    "day",
+                    "hour",
+                    "minute",
+                    "month",
+                    "quarter",
+                    "second",
+                    "week_day",
+                    "year",
+                ],
+            },
             "html": {"fields": {}, "sortedFields": []},
+            "month": {"fields": {}, "sortedFields": []},
             "number": {
                 "fields": {
                     "average": {
@@ -874,75 +1090,7 @@ snapshots["test_query_html_no_perms context"] = {
                 },
                 "sortedFields": ["count"],
             },
-            "time": {
-                "fields": {
-                    "count": {
-                        "concrete": True,
-                        "model": None,
-                        "prettyName": "count",
-                        "type": "number",
-                    },
-                    "day": {
-                        "concrete": True,
-                        "model": None,
-                        "prettyName": "day",
-                        "type": "number",
-                    },
-                    "hour": {
-                        "concrete": True,
-                        "model": None,
-                        "prettyName": "hour",
-                        "type": "number",
-                    },
-                    "minute": {
-                        "concrete": True,
-                        "model": None,
-                        "prettyName": "minute",
-                        "type": "number",
-                    },
-                    "month": {
-                        "concrete": True,
-                        "model": None,
-                        "prettyName": "month",
-                        "type": "number",
-                    },
-                    "quarter": {
-                        "concrete": True,
-                        "model": None,
-                        "prettyName": "quarter",
-                        "type": "number",
-                    },
-                    "second": {
-                        "concrete": True,
-                        "model": None,
-                        "prettyName": "second",
-                        "type": "number",
-                    },
-                    "week_day": {
-                        "concrete": True,
-                        "model": None,
-                        "prettyName": "week_day",
-                        "type": "number",
-                    },
-                    "year": {
-                        "concrete": True,
-                        "model": None,
-                        "prettyName": "year",
-                        "type": "number",
-                    },
-                },
-                "sortedFields": [
-                    "count",
-                    "day",
-                    "hour",
-                    "minute",
-                    "month",
-                    "quarter",
-                    "second",
-                    "week_day",
-                    "year",
-                ],
-            },
+            "weekday": {"fields": {}, "sortedFields": []},
         },
         "baseUrl": "/data_browser/",
         "savedViews": [],
@@ -958,12 +1106,62 @@ snapshots["test_query_html_no_perms context"] = {
                 },
                 "sortedLookups": ["equals", "not_equals", "is_null"],
             },
+            "date": {
+                "defaultLookup": "equals",
+                "defaultValue": "today",
+                "lookups": {
+                    "equals": {"type": "date"},
+                    "gt": {"type": "date"},
+                    "gte": {"type": "date"},
+                    "is_null": {"type": "boolean"},
+                    "lt": {"type": "date"},
+                    "lte": {"type": "date"},
+                    "not_equals": {"type": "date"},
+                },
+                "sortedLookups": [
+                    "equals",
+                    "not_equals",
+                    "gt",
+                    "gte",
+                    "lt",
+                    "lte",
+                    "is_null",
+                ],
+            },
+            "datetime": {
+                "defaultLookup": "equals",
+                "defaultValue": "now",
+                "lookups": {
+                    "equals": {"type": "datetime"},
+                    "gt": {"type": "datetime"},
+                    "gte": {"type": "datetime"},
+                    "is_null": {"type": "boolean"},
+                    "lt": {"type": "datetime"},
+                    "lte": {"type": "datetime"},
+                    "not_equals": {"type": "datetime"},
+                },
+                "sortedLookups": [
+                    "equals",
+                    "not_equals",
+                    "gt",
+                    "gte",
+                    "lt",
+                    "lte",
+                    "is_null",
+                ],
+            },
             "html": {
                 "defaultLookup": None,
                 "defaultValue": None,
                 "lookups": {},
                 "sortedLookups": [],
             },
+            "month": {
+                "defaultLookup": None,
+                "defaultValue": None,
+                "lookups": {},
+                "sortedLookups": [],
+            },
             "number": {
                 "defaultLookup": "equals",
                 "defaultValue": 0,
@@ -1016,27 +1214,11 @@ snapshots["test_query_html_no_perms context"] = {
                     "is_null",
                 ],
             },
-            "time": {
-                "defaultLookup": "equals",
-                "defaultValue": "now",
-                "lookups": {
-                    "equals": {"type": "time"},
-                    "gt": {"type": "time"},
-                    "gte": {"type": "time"},
-                    "is_null": {"type": "boolean"},
-                    "lt": {"type": "time"},
-                    "lte": {"type": "time"},
-                    "not_equals": {"type": "time"},
-                },
-                "sortedLookups": [
-                    "equals",
-                    "not_equals",
-                    "gt",
-                    "gte",
-                    "lt",
-                    "lte",
-                    "is_null",
-                ],
+            "weekday": {
+                "defaultLookup": None,
+                "defaultValue": None,
+                "lookups": {},
+                "sortedLookups": [],
             },
         },
         "version": "redacted",
@@ -1089,9 +1271,9 @@ snapshots["test_query_ctx context"] = {
                     },
                     "date_joined": {
                         "concrete": True,
-                        "model": "time",
+                        "model": "datetime",
                         "prettyName": "date_joined",
-                        "type": "time",
+                        "type": "datetime",
                     },
                     "email": {
                         "concrete": True,
@@ -1131,9 +1313,9 @@ snapshots["test_query_ctx context"] = {
                     },
                     "last_login": {
                         "concrete": True,
-                        "model": "time",
+                        "model": "datetime",
                         "prettyName": "last_login",
-                        "type": "time",
+                        "type": "datetime",
                     },
                     "last_name": {
                         "concrete": True,
@@ -1196,9 +1378,9 @@ snapshots["test_query_ctx context"] = {
                     },
                     "created_time": {
                         "concrete": True,
-                        "model": "time",
+                        "model": "datetime",
                         "prettyName": "created_time",
-                        "type": "time",
+                        "type": "datetime",
                     },
                     "description": {
                         "concrete": True,
@@ -1283,7 +1465,132 @@ snapshots["test_query_ctx context"] = {
                     "query",
                 ],
             },
+            "date": {
+                "fields": {
+                    "count": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "count",
+                        "type": "number",
+                    },
+                    "day": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "day",
+                        "type": "number",
+                    },
+                    "month": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "month",
+                        "type": "month",
+                    },
+                    "quarter": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "quarter",
+                        "type": "number",
+                    },
+                    "week_day": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "week_day",
+                        "type": "weekday",
+                    },
+                    "year": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "year",
+                        "type": "number",
+                    },
+                },
+                "sortedFields": [
+                    "count",
+                    "day",
+                    "month",
+                    "quarter",
+                    "week_day",
+                    "year",
+                ],
+            },
+            "datetime": {
+                "fields": {
+                    "count": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "count",
+                        "type": "number",
+                    },
+                    "date": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "date",
+                        "type": "date",
+                    },
+                    "day": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "day",
+                        "type": "number",
+                    },
+                    "hour": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "hour",
+                        "type": "number",
+                    },
+                    "minute": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "minute",
+                        "type": "number",
+                    },
+                    "month": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "month",
+                        "type": "month",
+                    },
+                    "quarter": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "quarter",
+                        "type": "number",
+                    },
+                    "second": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "second",
+                        "type": "number",
+                    },
+                    "week_day": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "week_day",
+                        "type": "weekday",
+                    },
+                    "year": {
+                        "concrete": True,
+                        "model": None,
+                        "prettyName": "year",
+                        "type": "number",
+                    },
+                },
+                "sortedFields": [
+                    "count",
+                    "date",
+                    "day",
+                    "hour",
+                    "minute",
+                    "month",
+                    "quarter",
+                    "second",
+                    "week_day",
+                    "year",
+                ],
+            },
             "html": {"fields": {}, "sortedFields": []},
+            "month": {"fields": {}, "sortedFields": []},
             "number": {
                 "fields": {
                     "average": {
@@ -1511,9 +1818,9 @@ snapshots["test_query_ctx context"] = {
                     },
                     "created_time": {
                         "concrete": True,
-                        "model": "time",
+                        "model": "datetime",
                         "prettyName": "created_time",
-                        "type": "time",
+                        "type": "datetime",
                     },
                     "default_sku": {
                         "concrete": False,
@@ -1630,75 +1937,7 @@ snapshots["test_query_ctx context"] = {
                 },
                 "sortedFields": ["id", "admin", "name"],
             },
-            "time": {
-                "fields": {
-                    "count": {
-                        "concrete": True,
-                        "model": None,
-                        "prettyName": "count",
-                        "type": "number",
-                    },
-                    "day": {
-                        "concrete": True,
-                        "model": None,
-                        "prettyName": "day",
-                        "type": "number",
-                    },
-                    "hour": {
-                        "concrete": True,
-                        "model": None,
-                        "prettyName": "hour",
-                        "type": "number",
-                    },
-                    "minute": {
-                        "concrete": True,
-                        "model": None,
-                        "prettyName": "minute",
-                        "type": "number",
-                    },
-                    "month": {
-                        "concrete": True,
-                        "model": None,
-                        "prettyName": "month",
-                        "type": "number",
-                    },
-                    "quarter": {
-                        "concrete": True,
-                        "model": None,
-                        "prettyName": "quarter",
-                        "type": "number",
-                    },
-                    "second": {
-                        "concrete": True,
-                        "model": None,
-                        "prettyName": "second",
-                        "type": "number",
-                    },
-                    "week_day": {
-                        "concrete": True,
-                        "model": None,
-                        "prettyName": "week_day",
-                        "type": "number",
-                    },
-                    "year": {
-                        "concrete": True,
-                        "model": None,
-                        "prettyName": "year",
-                        "type": "number",
-                    },
-                },
-                "sortedFields": [
-                    "count",
-                    "day",
-                    "hour",
-                    "minute",
-                    "month",
-                    "quarter",
-                    "second",
-                    "week_day",
-                    "year",
-                ],
-            },
+            "weekday": {"fields": {}, "sortedFields": []},
         },
         "baseUrl": "/data_browser/",
         "savedViews": [],
@@ -1726,12 +1965,62 @@ snapshots["test_query_ctx context"] = {
                 },
                 "sortedLookups": ["equals", "not_equals", "is_null"],
             },
+            "date": {
+                "defaultLookup": "equals",
+                "defaultValue": "today",
+                "lookups": {
+                    "equals": {"type": "date"},
+                    "gt": {"type": "date"},
+                    "gte": {"type": "date"},
+                    "is_null": {"type": "boolean"},
+                    "lt": {"type": "date"},
+                    "lte": {"type": "date"},
+                    "not_equals": {"type": "date"},
+                },
+                "sortedLookups": [
+                    "equals",
+                    "not_equals",
+                    "gt",
+                    "gte",
+                    "lt",
+                    "lte",
+                    "is_null",
+                ],
+            },
+            "datetime": {
+                "defaultLookup": "equals",
+                "defaultValue": "now",
+                "lookups": {
+                    "equals": {"type": "datetime"},
+                    "gt": {"type": "datetime"},
+                    "gte": {"type": "datetime"},
+                    "is_null": {"type": "boolean"},
+                    "lt": {"type": "datetime"},
+                    "lte": {"type": "datetime"},
+                    "not_equals": {"type": "datetime"},
+                },
+                "sortedLookups": [
+                    "equals",
+                    "not_equals",
+                    "gt",
+                    "gte",
+                    "lt",
+                    "lte",
+                    "is_null",
+                ],
+            },
             "html": {
                 "defaultLookup": None,
                 "defaultValue": None,
                 "lookups": {},
                 "sortedLookups": [],
             },
+            "month": {
+                "defaultLookup": None,
+                "defaultValue": None,
+                "lookups": {},
+                "sortedLookups": [],
+            },
             "number": {
                 "defaultLookup": "equals",
                 "defaultValue": 0,
@@ -1784,27 +2073,11 @@ snapshots["test_query_ctx context"] = {
                     "is_null",
                 ],
             },
-            "time": {
-                "defaultLookup": "equals",
-                "defaultValue": "now",
-                "lookups": {
-                    "equals": {"type": "time"},
-                    "gt": {"type": "time"},
-                    "gte": {"type": "time"},
-                    "is_null": {"type": "boolean"},
-                    "lt": {"type": "time"},
-                    "lte": {"type": "time"},
-                    "not_equals": {"type": "time"},
-                },
-                "sortedLookups": [
-                    "equals",
-                    "not_equals",
-                    "gt",
-                    "gte",
-                    "lt",
-                    "lte",
-                    "is_null",
-                ],
+            "weekday": {
+                "defaultLookup": None,
+                "defaultValue": None,
+                "lookups": {},
+                "sortedLookups": [],
             },
         },
         "version": "redacted",
