@@ -39,8 +39,8 @@ def test_query_html(admin_client, snapshot):
     )
     assert res.status_code == 200
     context = json.loads(res.context["ctx"])
-    context["config"]["types"]["time"]["defaultValue"] = "redacted"
     context["config"]["version"] = "redacted"
+    context["initialState"]["version"] = "redacted"
     snapshot.assert_match(context, "context")
 
 
@@ -50,8 +50,8 @@ def test_query_html_no_perms(admin_user, admin_client, snapshot):
     res = admin_client.get("/data_browser/query//.html?")
     assert res.status_code == 200
     context = json.loads(res.context["ctx"])
-    context["config"]["types"]["time"]["defaultValue"] = "redacted"
     context["config"]["version"] = "redacted"
+    context["initialState"]["version"] = "redacted"
     snapshot.assert_match(context, "context")
 
 
@@ -59,9 +59,12 @@ def test_query_ctx(admin_client, snapshot):
     res = admin_client.get("/data_browser/query//.ctx?")
     assert res.status_code == 200
     context = res.json()
-    context["config"]["types"]["time"]["defaultValue"] = "redacted"
     context["config"]["version"] = "redacted"
+    context["initialState"]["version"] = "redacted"
     snapshot.assert_match(context, "context")
+    with open("frontend/src/context_fixture.json", "w") as f:
+        json.dump(context, f, indent=4, sort_keys=True)
+        f.write("\n")
 
 
 @pytest.mark.usefixtures("products")
@@ -102,44 +105,14 @@ def test_query_csv(admin_client):
 
 
 @pytest.mark.usefixtures("products")
-def test_query_json(admin_client):
+def test_query_json(admin_client, snapshot):
     res = admin_client.get(
         "/data_browser/query/tests.Product/size-0,name+1,size_unit.json?size__lt=2&id__gt=0"
     )
     assert res.status_code == 200
     data = json.loads(res.content.decode("utf-8"))
-
-    dump(data)
-    assert data == {
-        "results": [[1, "a", "g"], [1, "b", "g"]],
-        "fields": [
-            {"path": ["size"], "prettyPath": ["size"], "priority": 0, "sort": "dsc"},
-            {"path": ["name"], "prettyPath": ["name"], "priority": 1, "sort": "asc"},
-            {
-                "path": ["size_unit"],
-                "prettyPath": ["size_unit"],
-                "priority": null,
-                "sort": null,
-            },
-        ],
-        "filters": [
-            {
-                "errorMessage": null,
-                "lookup": "lt",
-                "path": ["size"],
-                "prettyPath": ["size"],
-                "value": "2",
-            },
-            {
-                "errorMessage": null,
-                "lookup": "gt",
-                "path": ["id"],
-                "prettyPath": ["id"],
-                "value": "0",
-            },
-        ],
-        "model": "tests.Product",
-    }
+    data["version"] = "redacted"
+    snapshot.assert_match(data, "data")
 
 
 @pytest.mark.usefixtures("products")
